import React, { useState } from "react";
import { createRoot } from "react-dom/client";
import { createBrowserRouter, RouterProvider } from "react-router-dom";
import { MetadataSetter, ErrorPage, Login, ForgotPassword, Reset, Transactions } from "@components";
import UserContext from '@ts/userContext'

const router = createBrowserRouter([
  {
    path: "/",
    element:
      <MetadataSetter title="Transactions" bodyClass="transactions" needsAuth>
        <Transactions />
      </MetadataSetter>,
    errorElement:
      <MetadataSetter title="Error" bodyClass="error">
        <ErrorPage />
      </MetadataSetter>
  },
  {
    path: "/login",
    element:
      <MetadataSetter title="Login" bodyClass="login">
        <Login />
      </MetadataSetter>
  },
  {
    path: "/forgot",
    element:
      <MetadataSetter title="Forgot Password" bodyClass="forgot">
        <ForgotPassword />
      </MetadataSetter>
  },
  {
    path: "/reset",
    element:
      <MetadataSetter title="Reset Password" bodyClass="reset">
        <Reset />
      </MetadataSetter>
  },
]);


const App = function () {
  const [name, setName] = useState("John Smith")
  const userContextValue = { name, setName }
  return (
    <UserContext.Provider value={userContextValue}>
      <RouterProvider router={router} />
    </UserContext.Provider>
  )
}



createRoot(document.querySelector("#root")).render(
  <React.StrictMode>
    <App />
  </React.StrictMode>
);
